# Copyright (C) 2010 Thomson Reuters
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

version_info = (0, 3, 0)

from bzrlib.commands import plugin_cmds

from bzrlib.branch import (
    network_format_registry as branch_network_format_registry,
    InterBranch
    )

from bzrlib.bzrdir import (
    BzrDirFormat,
    format_registry,
    )

from bzrlib.transport import (
    register_lazy_transport,
    register_transport_proto,
    )

from bzrlib.repository import (
    network_format_registry as repository_network_format_registry,
    )

from bzrlib.foreign import (
    foreign_vcs_registry,
    )

register_transport_proto('tfs+http://',
    help="Access of TFS servers over HTTP.")

register_lazy_transport('tfs+', 'bzrlib.plugins.tfs.transport',
                        'TfsTransport')

from bzrlib.plugins.tfs.foreign import TfsControlFormat
BzrDirFormat.register_control_server_format(TfsControlFormat)

branch_network_format_registry.register_lazy("tfs",
        'bzrlib.plugins.tfs.branch', 'TfsBranchFormat')

repository_network_format_registry.register_lazy("tfs",
        'bzrlib.plugins.tfs.foreign', 'TfsRepositoryFormat')

format_registry.register_lazy("tfs", "bzrlib.plugins.tfs.foreign",
                         "TfsControlFormat",
                         "TFS repository. ",
                         native=False)

foreign_vcs_registry.register_lazy("tfs", "bzrlib.plugins.tfs.foreign",
                                   "foreign_vcs_tfs")

from bzrlib.repository import InterRepository
from bzrlib.plugins.tfs import convert
InterRepository.register_optimiser(convert.FromTfsRepository)
InterRepository.register_optimiser(convert.ToTfsRepository)

from bzrlib.plugins.tfs.branch import FromTfsBranch
InterBranch.register_optimiser(FromTfsBranch)

plugin_cmds.register_lazy('cmd_tfs_workspaces', [], 'bzrlib.plugins.tfs.commands')
plugin_cmds.register_lazy('cmd_tfs_serverinfo', [], 'bzrlib.plugins.tfs.commands')

def test_suite():
    """Return the plugin test suite."""
    from bzrlib.plugins.tfs import tests
    return tests.test_suite()

if __name__=="__main__":
    print ("This is a Bazaar plugin. Copy this directory to ~/.bazaar/plugins "
          "to use it.\n")
elif __name__ != 'bzrlib.plugins.tfs':
    raise ImportError('The Team Foundation Server plugin must be installed as'
                      ' bzrlib.plugins.tfs not %s' % __name__)
