# Copyright (C) 2010 Thomson Reuters
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

import urllib

from bzrlib import foreign
from bzrlib.errors import InvalidRevisionId
from bzrlib.plugins.tfs.foreign import foreign_vcs_tfs

class BzrTfsMapping(foreign.VcsMapping):
    """Class that maps between Bazaar and TFS semantics."""

    #whether this is experimental
    experimental = True
    #supports importing and exporting all semantics
    roundtripping = False
    revid_prefix = "tfs-v1:"

    def __init__(self):
        super(BzrTfsMapping, self).__init__(foreign_vcs_tfs)

    #convert to TFS id
    def revision_id_bzr_to_foreign(self, revid):
        if not revid.startswith(self.revid_prefix):
            raise InvalidRevisionId(revid, "")
        try:
            (version, path, changeset) = revid.split(":")
        except ValueError:
            raise InvalidRevisionId(revid, "")
        return (urllib.unquote(path), changeset)

    #convert to BZR id
    def revision_id_foreign_to_bzr(self, (path, changeset)):
        return "%s%s:%d" % (self.revid_prefix, urllib.quote(path), changeset)

